@@ -1,5 +1,10 @@
 def error(msg):
     return f"\n<error>{'ERRER'+' ':>12}</error>{msg}\n"
 
-def status(status,msg):
+
+def status(status, msg):
     return f"<status>{status+' ':>12}</status>{msg}"
+
+
+def success(status, msg):
+    return f"<success>{status+' ':>12}</success>{msg}"
