@@ -1,13 +1,15 @@
-from notion_client import Client #,AsyncClient
-import os,sys
-from notion2md.console.formatter import *
+import os
+import sys
+
+from notion_client import Client  # ,AsyncClient
+
 
 try:
     notion_client_object = Client(auth=os.environ["NOTION_TOKEN"])
-except:
+except Exception:
     print("Notion Integration Token is not found")
     print(
-    """
+        """
         Welcome to notion2md!
 
         To get started, you need to save your Notion Integration Token.
@@ -18,7 +20,7 @@ except:
         Then run shell command:
 
             $export NOTION_TOKEN="<Your Token>"
-        
+
         If you want to save this environment variable after reboot,
         put upper command in your shell resource(ex: .bashrc or .zshrc)
     """
@@ -26,5 +28,6 @@ except:
     sys.exit(1)
 # notion_async_client = AsyncClient(auth=os.environ["NOTION_TOKEN"])
 
+
 def get_children(parent_id):
-    return notion_client_object.blocks.children.list(parent_id)['results']
\ No newline at end of file
+    return notion_client_object.blocks.children.list(parent_id)["results"]
